.. _mentoring:

Mentorship Program
==================

Our goal, apart from improving aeon, is to onboard new contributors and we would really like you to stay around after your first visit to our project. Your help is extremely welcome!

For this reason, we have launched an informal mentorship programme over 2 - 3 months to onboard new contributors. The goal is to help new and/or anxious contributors to become more familiar with aeon, machine learning, and open-source software development.

We explicitly encourage students from underrepresented groups or who have experienced discrimination in the past to apply!

What we offer
-------------

* Mentorship programme for 2 - 3 months, depending on your availability;
* We will help you find an interesting topic to work on; or you can propose your own topic;
* We pair you with one a more experienced contributor; you can expect to have weekly calls with your mentor, in which you receive feedback on your work, can ask questions, and discuss the next steps.

We have an active community of researchers and students who work on sktime. We will onboard you and you will have time to socialize with other contributors and mentees in the community.

You can find our mentors in our `list of contributors <https://github.com/sktime/sktime/blob/main/CONTRIBUTORS.md>`_ by looking for the mentorship emoji: 🧑‍🏫.

To find out what current mentees are working, take a look at their `projects <https://github.com/sktime/mentoring/issues?q=is%3Aopen+is%3Aissue+label%3Amentoring>`__.

What we expect
--------------

We expect you to choose and work on sktime for a significant amount of time. Typically, we expect students to work 1 - 2 days per week for 2 - 3 months.

In addition to the individual project work, all students are be expected to:

* Regularly peer-review fellow contributors' work (PR reviews on GitHub),
* Discuss proposed changes online on GitHub issues,
* Write a final blog post about your contribution.

Please also read our `Code of Conduct <https://github.com/sktime/sktime/blob/main/docs/source/get_involved/code_of_conduct.rst>`_.

How to apply
------------

#. Make PR on `our main repo <https://github.com/sktime/sktime>`_ or contribute to sktime in any other way. Check out our `contributing guide <https://github.com/sktime/sktime/blob/main/CONTRIBUTING.md>`_ to get started! If you've contributed to sktime previously, you can go straight to step 2.
#. Submit an application through our `online form <https://forms.gle/WyXVMWzwzwLon47YA>`_.

We accept applications on a rolling basis and we will be in touch with you shortly!

If you have any questions or get stuck, please don't hesitate to `chat with us on slack <https://join.slack.com/t/scikit-timeworkspace/shared_invite/zt-1pkhua342-W_W24XuAZt2JZU1GniK2YA>`_.
